@@ -1,11 +1,11 @@
 # -*- coding: utf-8 -*-
 
 from .nonnormal import NonnormalMeshgrid, NonnormalMeshgridAuto, \
-    NonnormalTriang, NonnormalPoints
+    NonnormalTriang, NonnormalPoints, NonnormalAuto
 from .normal import Normal, NormalEvals
 from . import demo, utils
 
 __all__ = ['NonnormalMeshgrid', 'NonnormalMeshgridAuto', 'NonnormalTriang',
-           'NonnormalPoints',
+           'NonnormalPoints', 'NonnormalAuto',
            'Normal', 'NormalEvals',
            'demo', 'utils']
